Module: Aws::ElementalInference::Types
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AspectRatio, AssociateFeedRequest, AssociateFeedResponse, ClippingConfig, ConflictException, CreateDictionaryRequest, CreateDictionaryResponse, CreateFeedRequest, CreateFeedResponse, CreateOutput, CroppingConfig, DeleteDictionaryRequest, DeleteDictionaryResponse, DeleteFeedRequest, DeleteFeedResponse, DictionarySummary, DisassociateFeedRequest, DisassociateFeedResponse, ExportDictionaryEntriesRequest, ExportDictionaryEntriesResponse, FeedAssociation, FeedSummary, GetDictionaryRequest, GetDictionaryResponse, GetFeedRequest, GetFeedResponse, GetOutput, InternalServerErrorException, ListDictionariesRequest, ListDictionariesResponse, ListFeedsRequest, ListFeedsResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, OutputConfig, ResourceNotFoundException, ServiceQuotaExceededException, SubtitlingConfig, TagResourceRequest, TooManyRequestException, UntagResourceRequest, UpdateDictionaryRequest, UpdateDictionaryResponse, UpdateFeedRequest, UpdateFeedResponse, UpdateOutput, ValidationException
Instance Attribute Summary collapse
-
#clipping ⇒ Types::ClippingConfig
The output config type that applies to the clipping feature.
-
#cropping ⇒ Types::CroppingConfig
The output config type that applies to the cropping feature.
-
#subtitling ⇒ Types::SubtitlingConfig
The output config type that applies to the smart subtitling feature.
Instance Attribute Details
#clipping ⇒ Types::ClippingConfig
The output config type that applies to the clipping feature.
867 868 869 870 871 872 873 874 875 876 877 878 879 880 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 867 class OutputConfig < Struct.new( :cropping, :clipping, :subtitling, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Cropping < OutputConfig; end class Clipping < OutputConfig; end class Subtitling < OutputConfig; end class Unknown < OutputConfig; end end |
#cropping ⇒ Types::CroppingConfig
The output config type that applies to the cropping feature.
867 868 869 870 871 872 873 874 875 876 877 878 879 880 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 867 class OutputConfig < Struct.new( :cropping, :clipping, :subtitling, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Cropping < OutputConfig; end class Clipping < OutputConfig; end class Subtitling < OutputConfig; end class Unknown < OutputConfig; end end |
#subtitling ⇒ Types::SubtitlingConfig
The output config type that applies to the smart subtitling feature.
867 868 869 870 871 872 873 874 875 876 877 878 879 880 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 867 class OutputConfig < Struct.new( :cropping, :clipping, :subtitling, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Cropping < OutputConfig; end class Clipping < OutputConfig; end class Subtitling < OutputConfig; end class Unknown < OutputConfig; end end |