Class: Aws::ElementalInference::Types::Competitor

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Contains information about one competitor in a fixture. It is used in the FixtureSummary that is in the SearchFixtures response.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#is_homeBoolean

Specifies whether this competitor is the home side in the fixture. If true, this competitor is the home side. If false, this competitor is the away side.

Returns:

  • (Boolean)


152
153
154
155
156
157
# File 'lib/aws-sdk-elementalinference/types.rb', line 152

class Competitor < Struct.new(
  :name,
  :is_home)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the competitor, as provided by the data source.

Returns:

  • (String)


152
153
154
155
156
157
# File 'lib/aws-sdk-elementalinference/types.rb', line 152

class Competitor < Struct.new(
  :name,
  :is_home)
  SENSITIVE = []
  include Aws::Structure
end