Class: Aws::ElementalInference::Types::CreateDictionaryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::CreateDictionaryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the dictionary.
-
#id ⇒ String
A unique ID that Elemental Inference assigns to the dictionary.
-
#language ⇒ String
The language of the dictionary.
-
#name ⇒ String
The name that you specified in the request.
-
#references ⇒ Array<String>
A list of feed IDs that reference this dictionary.
-
#status ⇒ String
The current status of the dictionary.
-
#tags ⇒ Hash<String,String>
Any tags that you included when you created the dictionary.
Instance Attribute Details
#arn ⇒ String
The ARN of the dictionary.
200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 200 class CreateDictionaryResponse < Struct.new( :name, :arn, :id, :language, :status, :references, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique ID that Elemental Inference assigns to the dictionary.
200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 200 class CreateDictionaryResponse < Struct.new( :name, :arn, :id, :language, :status, :references, :tags) SENSITIVE = [] include Aws::Structure end |
#language ⇒ String
The language of the dictionary.
200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 200 class CreateDictionaryResponse < Struct.new( :name, :arn, :id, :language, :status, :references, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that you specified in the request.
200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 200 class CreateDictionaryResponse < Struct.new( :name, :arn, :id, :language, :status, :references, :tags) SENSITIVE = [] include Aws::Structure end |
#references ⇒ Array<String>
A list of feed IDs that reference this dictionary.
200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 200 class CreateDictionaryResponse < Struct.new( :name, :arn, :id, :language, :status, :references, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the dictionary. After creation succeeds, the status will be AVAILABLE.
200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 200 class CreateDictionaryResponse < Struct.new( :name, :arn, :id, :language, :status, :references, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Any tags that you included when you created the dictionary.
200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 200 class CreateDictionaryResponse < Struct.new( :name, :arn, :id, :language, :status, :references, :tags) SENSITIVE = [] include Aws::Structure end |