Class: Aws::ElementalInference::Types::CreateFeedResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_role_arnString

The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that you specified in the request. This property is absent if you didn't specify an IAM role.

Returns:

  • (String)


352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-elementalinference/types.rb', line 352

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

A unique ARN that Elemental Inference assigns to the feed.

Returns:

  • (String)


352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-elementalinference/types.rb', line 352

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#associationTypes::FeedAssociation

The association for this feed. When you create the feed, this property is empty. You must associate a resource with the feed using AssociateFeed or UpdateFeed.



352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-elementalinference/types.rb', line 352

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#data_endpointsArray<String>

An array of endpoints for the feed. Typically, there is only one endpoint. The feed receives source media at this endpoint (when the calling application calls PutMedia) and returns the resulting metadata to this endpoint (when the calling application calls GetMetadata).

Returns:

  • (Array<String>)


352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-elementalinference/types.rb', line 352

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique ID that Elemental Inference assigns to the feed.

Returns:

  • (String)


352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-elementalinference/types.rb', line 352

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name that you specified in the request.

Returns:

  • (String)


352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-elementalinference/types.rb', line 352

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::GetOutput>

Repeats the outputs that you specified in the request.

Returns:



352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-elementalinference/types.rb', line 352

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the feed. After creation of the feed has succeeded, the status will be AVAILABLE.

Returns:

  • (String)


352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-elementalinference/types.rb', line 352

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Any tags that you included when you created the feed.

Returns:

  • (Hash<String,String>)


352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-elementalinference/types.rb', line 352

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end