Class: Aws::ElementalInference::Types::CreateOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Contains configuration information about one output in a feed. It is used in the AssociateFeed and the CreateFeed actions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description for the output.

Returns:

  • (String)


316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-elementalinference/types.rb', line 316

class CreateOutput < Struct.new(
  :name,
  :output_config,
  :status,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the output.

Returns:

  • (String)


316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-elementalinference/types.rb', line 316

class CreateOutput < Struct.new(
  :name,
  :output_config,
  :status,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::OutputConfig

A typed property for an output in a feed. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.

Returns:



316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-elementalinference/types.rb', line 316

class CreateOutput < Struct.new(
  :name,
  :output_config,
  :status,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status to assign to the output.

Returns:

  • (String)


316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-elementalinference/types.rb', line 316

class CreateOutput < Struct.new(
  :name,
  :output_config,
  :status,
  :description)
  SENSITIVE = []
  include Aws::Structure
end