Class: Aws::ElementalInference::Types::CroppingConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

A type of OutputConfig, used when the output in a feed is for the crop feature.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#template_groupsArray<Types::TemplateGroup>

An array of template groups for the crop output. Each template group provides the graphics-compositing templates that Elemental Inference applies to the cropped video. You can specify from 1 to 4 template groups.

Returns:



346
347
348
349
350
# File 'lib/aws-sdk-elementalinference/types.rb', line 346

class CroppingConfig < Struct.new(
  :template_groups)
  SENSITIVE = []
  include Aws::Structure
end