Class: Aws::ElementalInference::Types::DisassociateFeedRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::DisassociateFeedRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_resource_name ⇒ String
The name of the resource currently associated with the feed.
-
#dry_run ⇒ Boolean
Set to true if you want to do a dry run of the disassociate action.
-
#id ⇒ String
The ID of the feed where you want to release the resource.
Instance Attribute Details
#associated_resource_name ⇒ String
The name of the resource currently associated with the feed.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
460 461 462 463 464 465 466 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 460 class DisassociateFeedRequest < Struct.new( :id, :associated_resource_name, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Set to true if you want to do a dry run of the disassociate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions. If the dry run fails, the action returns a 4xx error code.
460 461 462 463 464 465 466 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 460 class DisassociateFeedRequest < Struct.new( :id, :associated_resource_name, :dry_run) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the feed where you want to release the resource.
460 461 462 463 464 465 466 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 460 class DisassociateFeedRequest < Struct.new( :id, :associated_resource_name, :dry_run) SENSITIVE = [] include Aws::Structure end |