Class: Aws::ElementalInference::Types::FeedAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::FeedAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Contains information about the resource that is associated with a feed. It is used in the FeedSummary that is used in the response of a ListFeeds action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_resource_name ⇒ String
The name of the associated resource.
Instance Attribute Details
#associated_resource_name ⇒ String
The name of the associated resource.
314 315 316 317 318 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 314 class FeedAssociation < Struct.new( :associated_resource_name) SENSITIVE = [] include Aws::Structure end |