Class: Aws::ElementalInference::Types::GetFixtureResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::GetFixtureResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#competitors ⇒ Array<Types::Competitor>
An array of the competitors (the teams or individuals) in the fixture.
-
#fixture_group ⇒ String
The group that the fixture belongs to, such as the competition, league, or tournament.
-
#fixture_id ⇒ String
The ID that you specified in the request.
-
#name ⇒ String
The name of the fixture, as provided by the data source.
-
#scheduled_start ⇒ Time
The scheduled start time of the fixture, as provided by the data source.
-
#status ⇒ String
The status of the fixture in its lifecycle, as provided by the data source.
Instance Attribute Details
#competitors ⇒ Array<Types::Competitor>
An array of the competitors (the teams or individuals) in the fixture.
936 937 938 939 940 941 942 943 944 945 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 936 class GetFixtureResponse < Struct.new( :fixture_id, :name, :fixture_group, :scheduled_start, :status, :competitors) SENSITIVE = [] include Aws::Structure end |
#fixture_group ⇒ String
The group that the fixture belongs to, such as the competition, league, or tournament. The data source doesn't provide this information for every fixture.
936 937 938 939 940 941 942 943 944 945 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 936 class GetFixtureResponse < Struct.new( :fixture_id, :name, :fixture_group, :scheduled_start, :status, :competitors) SENSITIVE = [] include Aws::Structure end |
#fixture_id ⇒ String
The ID that you specified in the request.
936 937 938 939 940 941 942 943 944 945 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 936 class GetFixtureResponse < Struct.new( :fixture_id, :name, :fixture_group, :scheduled_start, :status, :competitors) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the fixture, as provided by the data source. For example, the names of the two competing teams.
936 937 938 939 940 941 942 943 944 945 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 936 class GetFixtureResponse < Struct.new( :fixture_id, :name, :fixture_group, :scheduled_start, :status, :competitors) SENSITIVE = [] include Aws::Structure end |
#scheduled_start ⇒ Time
The scheduled start time of the fixture, as provided by the data source. The actual start time might differ.
936 937 938 939 940 941 942 943 944 945 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 936 class GetFixtureResponse < Struct.new( :fixture_id, :name, :fixture_group, :scheduled_start, :status, :competitors) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the fixture in its lifecycle, as provided by the data source. For example, Scheduled or Completed.
936 937 938 939 940 941 942 943 944 945 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 936 class GetFixtureResponse < Struct.new( :fixture_id, :name, :fixture_group, :scheduled_start, :status, :competitors) SENSITIVE = [] include Aws::Structure end |