Class: Aws::ElementalInference::Types::ListDictionariesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return per API request. Valid range: 1 to 100.

Returns:

  • (Integer)


1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-elementalinference/types.rb', line 1016

class ListDictionariesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token that identifies the next batch of results to return.

Returns:

  • (String)


1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-elementalinference/types.rb', line 1016

class ListDictionariesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end