Class: Aws::ElementalInference::Types::ListFeedsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return per API request.

For example, you submit a list request with MaxResults set at 5. Although 20 items match your request, the service returns no more than the first 5 items. (The service also returns a NextToken value that you can use to fetch the next batch of results.)

The service might return fewer results than the MaxResults value. If MaxResults is not included in the request, the service defaults to pagination with a maximum of 10 results per page.

Valid Range: Minimum value of 1. Maximum value of 1000.

Returns:

  • (Integer)


1066
1067
1068
1069
1070
1071
# File 'lib/aws-sdk-elementalinference/types.rb', line 1066

class ListFeedsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token that identifies the batch of results that you want to see.

For example, you submit a ListFeeds request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the ListFeeds request a second time and specify the NextToken value.

Returns:

  • (String)


1066
1067
1068
1069
1070
1071
# File 'lib/aws-sdk-elementalinference/types.rb', line 1066

class ListFeedsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end