Class: Aws::ElementalInference::Types::ListFeedsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#feedsArray<Types::FeedSummary>

A list of FeedSummary objects.

Returns:



1087
1088
1089
1090
1091
1092
# File 'lib/aws-sdk-elementalinference/types.rb', line 1087

class ListFeedsResponse < Struct.new(
  :feeds,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token that identifies the batch of results that you want to see. For example, you submit a list request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the list request a second time and specify the NextToken value.

Returns:

  • (String)


1087
1088
1089
1090
1091
1092
# File 'lib/aws-sdk-elementalinference/types.rb', line 1087

class ListFeedsResponse < Struct.new(
  :feeds,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end