Class: Aws::ElementalInference::Types::PutFeedPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::PutFeedPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the feed to attach the policy to.
-
#policy ⇒ String
The resource-based policy document to attach to the feed.
Instance Attribute Details
#id ⇒ String
The ID of the feed to attach the policy to.
1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1171 class PutFeedPolicyRequest < Struct.new( :id, :policy) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ String
The resource-based policy document to attach to the feed.
1171 1172 1173 1174 1175 1176 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1171 class PutFeedPolicyRequest < Struct.new( :id, :policy) SENSITIVE = [] include Aws::Structure end |