Class: Aws::ElementalInference::Types::TooManyRequestException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::TooManyRequestException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
The request was denied due to request throttling. Too many requests have been made within a given time period. Reduce the frequency of requests and use exponential backoff when retrying.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
635 636 637 638 639 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 635 class TooManyRequestException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |