Class: Aws::ElementalInference::Waiters::FeedDeleted
- Inherits:
-
Object
- Object
- Aws::ElementalInference::Waiters::FeedDeleted
- Defined in:
- lib/aws-sdk-elementalinference/waiters.rb
Overview
Wait until a Feed is deleted
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ FeedDeleted
constructor
A new instance of FeedDeleted.
-
#wait(params = {}) ⇒ Types::GetFeedResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ FeedDeleted
Returns a new instance of FeedDeleted.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/aws-sdk-elementalinference/waiters.rb', line 85 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 40, delay: 3, poller: Aws::Waiters::Poller.new( operation_name: :get_feed, acceptors: [ { "matcher" => "error", "state" => "success", "expected" => "ResourceNotFoundException" }, { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "DELETED" }, { "matcher" => "path", "argument" => "status", "state" => "retry", "expected" => "DELETING" }, { "matcher" => "error", "state" => "retry", "expected" => "InternalServerErrorException" }, { "matcher" => "error", "state" => "retry", "expected" => "TooManyRequestException" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
132 133 134 |
# File 'lib/aws-sdk-elementalinference/waiters.rb', line 132 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetFeedResponse
Returns a response object which responds to the following methods:
-
#arn => String
-
#name => String
-
#id => String
-
#data_endpoints => Array<String>
-
#outputs => Array<Types::GetOutput>
-
#status => String
-
#association => Types::FeedAssociation
-
#tags => Hash<String,String>
127 128 129 |
# File 'lib/aws-sdk-elementalinference/waiters.rb', line 127 def wait(params = {}) @waiter.wait(client: @client, params: params) end |