Module: Aws::ElementalInference

Defined in:
lib/aws-sdk-elementalinference/endpoint_parameters.rb,
lib/aws-sdk-elementalinference/plugins/endpoints.rb,
lib/aws-sdk-elementalinference/endpoint_provider.rb,
lib/aws-sdk-elementalinference/client_api.rb,
lib/aws-sdk-elementalinference/endpoints.rb,
lib/aws-sdk-elementalinference/resource.rb,
lib/aws-sdk-elementalinference/waiters.rb,
lib/aws-sdk-elementalinference/errors.rb,
lib/aws-sdk-elementalinference/client.rb,
lib/aws-sdk-elementalinference/types.rb,
lib/aws-sdk-elementalinference.rb

Overview

This module provides support for AWS Elemental Inference. This module is available in the ‘aws-sdk-elementalinference` gem.

# Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

elemental_inference = Aws::ElementalInference::Client.new
resp = elemental_inference.associate_feed(params)

See Client for more information.

# Errors

Errors returned from AWS Elemental Inference are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::ElementalInference::Errors::ServiceError
  # rescues all AWS Elemental Inference API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.3.0'