Class: Aws::ElementalInference::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
ClientStubs
Defined in:
lib/aws-sdk-elementalinference/client.rb

Overview

An API client for ElementalInference. To construct a client, you need to configure a ‘:region` and `:credentials`.

client = Aws::ElementalInference::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).

See #initialize for a full list of supported configuration options.

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :plugins (Array<Seahorse::Client::Plugin>) — default: []]

    A list of plugins to apply to the client. Each plugin is either a class name or an instance of a plugin class.

  • :credentials (required, Aws::CredentialProvider)

    Your AWS credentials used for authentication. This can be any class that includes and implements ‘Aws::CredentialProvider`, or instance of any one of the following classes:

    • ‘Aws::Credentials` - Used for configuring static, non-refreshing credentials.

    • ‘Aws::SharedCredentials` - Used for loading static credentials from a shared file, such as `~/.aws/config`.

    • ‘Aws::AssumeRoleCredentials` - Used when you need to assume a role.

    • ‘Aws::AssumeRoleWebIdentityCredentials` - Used when you need to assume a role after providing credentials via the web.

    • ‘Aws::SSOCredentials` - Used for loading credentials from AWS SSO using an access token generated from `aws login`.

    • ‘Aws::ProcessCredentials` - Used for loading credentials from a process that outputs to stdout.

    • ‘Aws::InstanceProfileCredentials` - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • ‘Aws::ECSCredentials` - Used for loading credentials from instances running in ECS.

    • ‘Aws::CognitoIdentityCredentials` - Used for loading credentials from the Cognito Identity service.

    When ‘:credentials` are not configured directly, the following locations will be searched for credentials:

    • Aws.config`

    • The ‘:access_key_id`, `:secret_access_key`, `:session_token`, and `:account_id` options.

    • ENV`, `ENV`, `ENV`, and `ENV`.

    • ‘~/.aws/credentials`

    • ‘~/.aws/config`

    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of ‘Aws::InstanceProfileCredentials` or `Aws::ECSCredentials` to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting `ENV` to `true`.

  • :region (required, String)

    The AWS region to connect to. The configured ‘:region` is used to determine the service `:endpoint`. When not passed, a default `:region` is searched for in the following locations:

  • :access_key_id (String)
  • :account_id (String)
  • :active_endpoint_cache (Boolean) — default: false

    When set to ‘true`, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to `false`.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true

    Used only in ‘adaptive` retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a `RetryCapacityNotAvailableError` and will not retry instead of sleeping.

  • :auth_scheme_preference (Array<String>)

    A list of preferred authentication schemes to use when making a request. Supported values are: ‘sigv4`, `sigv4a`, `httpBearerAuth`, and `noAuth`. When set using `ENV` or in shared config as `auth_scheme_preference`, the value should be a comma-separated list.

  • :client_side_monitoring (Boolean) — default: false

    When ‘true`, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: ""

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1"

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true

    When ‘true`, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true

    Used only in ‘standard` and `adaptive` retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy"

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false

    When ‘true`, the SDK will not prepend the modeled host prefix to the endpoint.

  • :disable_request_compression (Boolean) — default: false

    When set to ‘true’ the request body will not be compressed for supported operations.

  • :endpoint (String, URI::HTTPS, URI::HTTP)

    Normally you should not configure the ‘:endpoint` option directly. This is normally constructed from the `:region` option. Configuring `:endpoint` is normally reserved for connecting to test or custom endpoints. The endpoint should be a URI formatted like:

    'http://example.com'
    'https://example.com'
    'http://example.com:123'
    
  • :endpoint_cache_max_entries (Integer) — default: 1000

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false

    When set to ‘true`, endpoint discovery will be enabled for operations when available.

  • :ignore_configured_endpoint_urls (Boolean)

    Setting to true disables use of endpoint URLs provided via environment variables and the shared configuration file.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default

    The log formatter.

  • :log_level (Symbol) — default: :info

    The log level to send messages to the ‘:logger` at.

  • :logger (Logger)

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in ‘standard` and `adaptive` retry modes.

  • :profile (String) — default: "default"

    Used when loading credentials from the shared credentials file at ‘HOME/.aws/credentials`. When not specified, ’default’ is used.

  • :request_checksum_calculation (String) — default: "when_supported"

    Determines when a checksum will be calculated for request payloads. Values are:

    • ‘when_supported` - (default) When set, a checksum will be calculated for all request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` and/or a `requestAlgorithmMember` is modeled.

    • ‘when_required` - When set, a checksum will only be calculated for request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` or where a `requestAlgorithmMember` is modeled and supplied.

  • :request_min_compression_size_bytes (Integer) — default: 10240

    The minimum size in bytes that triggers compression for request bodies. The value must be non-negative integer value between 0 and 10485780 bytes inclusive.

  • :response_checksum_validation (String) — default: "when_supported"

    Determines when checksum validation will be performed on response payloads. Values are:

    • ‘when_supported` - (default) When set, checksum validation is performed on all response payloads of operations modeled with the `httpChecksum` trait where `responseAlgorithms` is modeled, except when no modeled checksum algorithms are supported.

    • ‘when_required` - When set, checksum validation is not performed on response payloads of operations unless the checksum algorithm is supported and the `requestValidationModeMember` member is set to `ENABLED`.

  • :retry_backoff (Proc)

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the ‘legacy` retry mode.

  • :retry_base_delay (Float) — default: 0.3

    The base delay in seconds used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_jitter (Symbol) — default: :none

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the ‘legacy` retry mode.

    @see www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the ‘legacy` retry mode.

  • :retry_max_delay (Integer) — default: 0

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_mode (String) — default: "legacy"

    Specifies which retry algorithm to use. Values are:

    • ‘legacy` - The pre-existing retry behavior. This is the default value if no retry mode is provided.

    • ‘standard` - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • ‘adaptive` - A retry mode that includes all the functionality of `standard` mode along with automatic client side throttling.

  • :sdk_ua_app_id (String)

    A unique and opaque application ID that is appended to the User-Agent header as app/sdk_ua_app_id. It should have a maximum length of 50. This variable is sourced from environment variable AWS_SDK_UA_APP_ID or the shared config profile attribute sdk_ua_app_id.

  • :secret_access_key (String)
  • :session_token (String)
  • :sigv4a_signing_region_set (Array)

    A list of regions that should be signed with SigV4a signing. When not passed, a default ‘:sigv4a_signing_region_set` is searched for in the following locations:

  • :stub_responses (Boolean) — default: false

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :telemetry_provider (Aws::Telemetry::TelemetryProviderBase) — default: Aws::Telemetry::NoOpTelemetryProvider

    Allows you to provide a telemetry provider, which is used to emit telemetry data. By default, uses ‘NoOpTelemetryProvider` which will not record or emit any telemetry data. The SDK supports the following telemetry providers:

    • OpenTelemetry (OTel) - To use the OTel provider, install and require the

    ‘opentelemetry-sdk` gem and then, pass in an instance of a `Aws::Telemetry::OTelProvider` for telemetry provider.

  • :token_provider (Aws::TokenProvider)

    Your Bearer token used for authentication. This can be any class that includes and implements ‘Aws::TokenProvider`, or instance of any one of the following classes:

    • ‘Aws::StaticTokenProvider` - Used for configuring static, non-refreshing tokens.

    • ‘Aws::SSOTokenProvider` - Used for loading tokens from AWS SSO using an access token generated from `aws login`.

    When ‘:token_provider` is not configured directly, the `Aws::TokenProviderChain` will be used to search for tokens configured for your profile in shared configuration files.

  • :use_dualstack_endpoint (Boolean)

    When set to ‘true`, dualstack enabled endpoints (with `.aws` TLD) will be used if available.

  • :use_fips_endpoint (Boolean)

    When set to ‘true`, fips compatible endpoints will be used if available. When a `fips` region is used, the region is normalized and this config is set to `true`.

  • :validate_params (Boolean) — default: true

    When ‘true`, request parameters are validated before sending the request.

  • :endpoint_provider (Aws::ElementalInference::EndpointProvider)

    The endpoint provider used to resolve endpoints. Any object that responds to ‘#resolve_endpoint(parameters)` where `parameters` is a Struct similar to `Aws::ElementalInference::EndpointParameters`.

  • :http_continue_timeout (Float) — default: 1

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has “Expect” header set to “100-continue”. Defaults to ‘nil` which disables this behaviour. This value can safely be set per request on the session.

  • :http_idle_timeout (Float) — default: 5

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_open_timeout (Float) — default: 15

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_proxy (URI::HTTP, String)

    A proxy to send requests through. Formatted like ‘proxy.com:123’.

  • :http_read_timeout (Float) — default: 60

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_wire_trace (Boolean) — default: false

    When ‘true`, HTTP debug output will be sent to the `:logger`.

  • :on_chunk_received (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the response body is received. It provides three arguments: the chunk, the number of bytes received, and the total number of bytes in the response (or nil if the server did not send a ‘content-length`).

  • :on_chunk_sent (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the request body is sent. It provides three arguments: the chunk, the number of bytes read from the body, and the total number of bytes in the body.

  • :raise_response_errors (Boolean) — default: true

    When ‘true`, response errors are raised.

  • :ssl_ca_bundle (String)

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_directory (String)

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_store (String)

    Sets the X509::Store to verify peer certificate.

  • :ssl_cert (OpenSSL::X509::Certificate)

    Sets a client certificate when creating http connections.

  • :ssl_key (OpenSSL::PKey)

    Sets a client key when creating http connections.

  • :ssl_timeout (Float)

    Sets the SSL timeout in seconds

  • :ssl_verify_peer (Boolean) — default: true

    When ‘true`, SSL peer certificates are verified when establishing a connection.



471
472
473
# File 'lib/aws-sdk-elementalinference/client.rb', line 471

def initialize(*args)
  super
end

Class Attribute Details

.identifierObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1470
1471
1472
# File 'lib/aws-sdk-elementalinference/client.rb', line 1470

def identifier
  @identifier
end

Class Method Details

.errors_moduleObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1473
1474
1475
# File 'lib/aws-sdk-elementalinference/client.rb', line 1473

def errors_module
  Errors
end

Instance Method Details

#associate_feed(params = {}) ⇒ Types::AssociateFeedResponse

Associates a resource with the feed. The resource provides the input that Elemental Inference needs in order to perform an Elemental Inference feature, such as cropping video. You always provide the resource by associating it with a feed. You can associate only one resource with each feed. With an association, a specific source media is claiming ownership of the feed.

AssociateFeed is a PATCH operation, which means that you can include only parameters that you want to change. Parameters that you don’t include will not be affected by the operation.

Specifically:

  • You can add more outputs to the existing outputs. New outputs will be appended.

  • You can’t modify an existing output (for example to change its name). Instead, use UpdateFeed.

  • You can’t delete an existing output. Instead, use UpdateFeed.

Also note that you can’t change the feed name with AssociateFeed. Instead, use UpdateFeed.

Examples:

Request syntax with placeholder values


resp = client.associate_feed({
  id: "FeedId", # required
  associated_resource_name: "AssociatedResourceName", # required
  outputs: [ # required
    {
      name: "ResourceName", # required
      output_config: { # required
        cropping: {
        },
        clipping: {
          callback_metadata: "ResourceDescription",
        },
        subtitling: {
          language: "eng", # required, accepts eng, eng-au, eng-gb, eng-us, fra, ita, deu, spa, por
          aspect_ratio: {
            width: 1, # required
            height: 1, # required
          },
          dictionary: "DictionaryId",
          profanity_filter: "DISABLED", # accepts DISABLED, CENSOR, DROP
        },
      },
      status: "ENABLED", # required, accepts ENABLED, DISABLED
      description: "ResourceDescription",
    },
  ],
  dry_run: false,
})

Response structure


resp.arn #=> String
resp.id #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :id (required, String)

    The ID of the feed.

  • :associated_resource_name (required, String)

    An identifier for the resource. This name must not resemble an ARN.

    The resource is the source media that the feed will process. The name you assign should help you to later identify the source media that belongs to the feed. In this way, you will know which source media to push to the feed (using PutMedia).

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

  • :outputs (required, Array<Types::CreateOutput>)

    An array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.

  • :dry_run (Boolean)

    Set to true if you want to do a dry run of the associate action.

    Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions, quota limits exceeded, conflicting outputs, and so on. If the dry run fails, the action returns a 4xx error code. After you’ve fixed the errors, resubmit the request.

Returns:

See Also:



574
575
576
577
# File 'lib/aws-sdk-elementalinference/client.rb', line 574

def associate_feed(params = {}, options = {})
  req = build_request(:associate_feed, params)
  req.send_request(options)
end

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
# File 'lib/aws-sdk-elementalinference/client.rb', line 1330

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  tracer = config.telemetry_provider.tracer_provider.tracer(
    Aws::Telemetry.module_to_tracer_name('Aws::ElementalInference')
  )
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config,
    tracer: tracer
  )
  context[:gem_name] = 'aws-sdk-elementalinference'
  context[:gem_version] = '1.5.0'
  Seahorse::Client::Request.new(handlers, context)
end

#create_dictionary(params = {}) ⇒ Types::CreateDictionaryResponse

Creates a custom dictionary for improving transcription accuracy. A dictionary contains custom words and phrases that the ASR engine might not recognize, such as brand names, technical terms, or proper nouns. You can reference a dictionary when configuring a smart subtitles output.

Examples:

Request syntax with placeholder values


resp = client.create_dictionary({
  name: "ResourceName", # required
  language: "eng", # required, accepts eng, fra, ita, deu, spa, por
  entries: "DictionaryEntriesPayload",
  tags: {
    "TagKey" => "TagValue",
  },
})

Response structure


resp.name #=> String
resp.arn #=> String
resp.id #=> String
resp.language #=> String, one of "eng", "fra", "ita", "deu", "spa", "por"
resp.status #=> String, one of "CREATING", "AVAILABLE", "REFERENCED", "DELETING", "DELETED"
resp.references #=> Array
resp.references[0] #=> String
resp.tags #=> Hash
resp.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :name (required, String)

    A user-friendly name for this dictionary.

  • :language (required, String)

    The language of the dictionary entries. Specify the language using an ISO 639-2/T three-letter code. Supported values: eng, fra, ita, deu, spa, por.

  • :entries (String)

    The dictionary entries payload. Contains the custom words and phrases for the dictionary. Maximum size is 40,960 characters.

  • :tags (Hash<String,String>)

    Optional tags to associate with the dictionary.

Returns:

See Also:



637
638
639
640
# File 'lib/aws-sdk-elementalinference/client.rb', line 637

def create_dictionary(params = {}, options = {})
  req = build_request(:create_dictionary, params)
  req.send_request(options)
end

#create_feed(params = {}) ⇒ Types::CreateFeedResponse

Creates a feed. The feed is the target for the live media stream that is being sent by the calling application. An example of a calling application is AWS Elemental MediaLive.

The key contents of the feed is an array of outputs. Each output represents an Elemental Inference feature. After you create the feed, you must associate a resource with the feed. At that point, you will have a useable feed: resource - feed - output or outputs.

Examples:

Request syntax with placeholder values


resp = client.create_feed({
  name: "ResourceName", # required
  outputs: [ # required
    {
      name: "ResourceName", # required
      output_config: { # required
        cropping: {
        },
        clipping: {
          callback_metadata: "ResourceDescription",
        },
        subtitling: {
          language: "eng", # required, accepts eng, eng-au, eng-gb, eng-us, fra, ita, deu, spa, por
          aspect_ratio: {
            width: 1, # required
            height: 1, # required
          },
          dictionary: "DictionaryId",
          profanity_filter: "DISABLED", # accepts DISABLED, CENSOR, DROP
        },
      },
      status: "ENABLED", # required, accepts ENABLED, DISABLED
      description: "ResourceDescription",
    },
  ],
  tags: {
    "TagKey" => "TagValue",
  },
})

Response structure


resp.arn #=> String
resp.name #=> String
resp.id #=> String
resp.data_endpoints #=> Array
resp.data_endpoints[0] #=> String
resp.outputs #=> Array
resp.outputs[0].name #=> String
resp.outputs[0].output_config.clipping. #=> String
resp.outputs[0].output_config.subtitling.language #=> String, one of "eng", "eng-au", "eng-gb", "eng-us", "fra", "ita", "deu", "spa", "por"
resp.outputs[0].output_config.subtitling.aspect_ratio.width #=> Integer
resp.outputs[0].output_config.subtitling.aspect_ratio.height #=> Integer
resp.outputs[0].output_config.subtitling.dictionary #=> String
resp.outputs[0].output_config.subtitling.profanity_filter #=> String, one of "DISABLED", "CENSOR", "DROP"
resp.outputs[0].status #=> String, one of "ENABLED", "DISABLED"
resp.outputs[0].description #=> String
resp.outputs[0].from_association #=> Boolean
resp.status #=> String, one of "CREATING", "AVAILABLE", "ACTIVE", "UPDATING", "DELETING", "DELETED", "ARCHIVED"
resp.association.associated_resource_name #=> String
resp.tags #=> Hash
resp.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :name (required, String)

    A user-friendly name for this feed.

  • :outputs (required, Array<Types::CreateOutput>)

    An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, there is one output type for the smart crop feature. You must specify at least one output, but you can later add outputs using AssociateFeed, or add, modify, and delete outputs using UpdateFeed.

  • :tags (Hash<String,String>)

    Optional tags. You can also add tags later, using TagResource.

Returns:

See Also:



734
735
736
737
# File 'lib/aws-sdk-elementalinference/client.rb', line 734

def create_feed(params = {}, options = {})
  req = build_request(:create_feed, params)
  req.send_request(options)
end

#delete_dictionary(params = {}) ⇒ Types::DeleteDictionaryResponse

Deletes the specified dictionary. You cannot delete a dictionary that is referenced by a feed. You must first remove the dictionary reference from the feed’s subtitling configuration.

Examples:

Request syntax with placeholder values


resp = client.delete_dictionary({
  id: "DictionaryId", # required
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.status #=> String, one of "CREATING", "AVAILABLE", "REFERENCED", "DELETING", "DELETED"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :id (required, String)

    The ID of the dictionary to delete.

Returns:

See Also:



768
769
770
771
# File 'lib/aws-sdk-elementalinference/client.rb', line 768

def delete_dictionary(params = {}, options = {})
  req = build_request(:delete_dictionary, params)
  req.send_request(options)
end

#delete_feed(params = {}) ⇒ Types::DeleteFeedResponse

Deletes the specified feed. You can delete the feed at any time. Elemental Inference doesn’t block you from deleting a feed when the calling application is calling PutMedia or GetMetadata on that feed, although both these calls will start to fail. For more information about managing inactive feeds, see the Elemental Inference User Guide.

Examples:

Request syntax with placeholder values


resp = client.delete_feed({
  id: "FeedId", # required
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.status #=> String, one of "CREATING", "AVAILABLE", "ACTIVE", "UPDATING", "DELETING", "DELETED", "ARCHIVED"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :id (required, String)

    The ID of the feed.

Returns:

See Also:



804
805
806
807
# File 'lib/aws-sdk-elementalinference/client.rb', line 804

def delete_feed(params = {}, options = {})
  req = build_request(:delete_feed, params)
  req.send_request(options)
end

#disassociate_feed(params = {}) ⇒ Types::DisassociateFeedResponse

Releases the resource (the source media) that is associated with this feed. The outputs in the feed become DISABLED.

Examples:

Request syntax with placeholder values


resp = client.disassociate_feed({
  id: "FeedId", # required
  associated_resource_name: "AssociatedResourceName", # required
  dry_run: false,
})

Response structure


resp.arn #=> String
resp.id #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :id (required, String)

    The ID of the feed where you want to release the resource.

  • :associated_resource_name (required, String)

    The name of the resource currently associated with the feed.

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

  • :dry_run (Boolean)

    Set to true if you want to do a dry run of the disassociate action.

    Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions. If the dry run fails, the action returns a 4xx error code.

Returns:

See Also:



851
852
853
854
# File 'lib/aws-sdk-elementalinference/client.rb', line 851

def disassociate_feed(params = {}, options = {})
  req = build_request(:disassociate_feed, params)
  req.send_request(options)
end

#export_dictionary_entries(params = {}) ⇒ Types::ExportDictionaryEntriesResponse

Exports the entries from the specified dictionary.

Examples:

Request syntax with placeholder values


resp = client.export_dictionary_entries({
  id: "DictionaryId", # required
})

Response structure


resp.data.entries #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :id (required, String)

    The ID of the dictionary whose entries you want to export.

Returns:

See Also:



879
880
881
882
# File 'lib/aws-sdk-elementalinference/client.rb', line 879

def export_dictionary_entries(params = {}, options = {})
  req = build_request(:export_dictionary_entries, params)
  req.send_request(options)
end

#get_dictionary(params = {}) ⇒ Types::GetDictionaryResponse

Retrieves information about the specified dictionary.

Examples:

Request syntax with placeholder values


resp = client.get_dictionary({
  id: "DictionaryId", # required
})

Response structure


resp.name #=> String
resp.arn #=> String
resp.id #=> String
resp.language #=> String, one of "eng", "fra", "ita", "deu", "spa", "por"
resp.status #=> String, one of "CREATING", "AVAILABLE", "REFERENCED", "DELETING", "DELETED"
resp.references #=> Array
resp.references[0] #=> String
resp.tags #=> Hash
resp.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :id (required, String)

    The ID of the dictionary to retrieve.

Returns:

See Also:



921
922
923
924
# File 'lib/aws-sdk-elementalinference/client.rb', line 921

def get_dictionary(params = {}, options = {})
  req = build_request(:get_dictionary, params)
  req.send_request(options)
end

#get_feed(params = {}) ⇒ Types::GetFeedResponse

Retrieves information about the specified feed.

The following waiters are defined for this operation (see #wait_until for detailed usage):

* feed_deleted

Examples:

Request syntax with placeholder values


resp = client.get_feed({
  id: "FeedId", # required
})

Response structure


resp.arn #=> String
resp.name #=> String
resp.id #=> String
resp.data_endpoints #=> Array
resp.data_endpoints[0] #=> String
resp.outputs #=> Array
resp.outputs[0].name #=> String
resp.outputs[0].output_config.clipping. #=> String
resp.outputs[0].output_config.subtitling.language #=> String, one of "eng", "eng-au", "eng-gb", "eng-us", "fra", "ita", "deu", "spa", "por"
resp.outputs[0].output_config.subtitling.aspect_ratio.width #=> Integer
resp.outputs[0].output_config.subtitling.aspect_ratio.height #=> Integer
resp.outputs[0].output_config.subtitling.dictionary #=> String
resp.outputs[0].output_config.subtitling.profanity_filter #=> String, one of "DISABLED", "CENSOR", "DROP"
resp.outputs[0].status #=> String, one of "ENABLED", "DISABLED"
resp.outputs[0].description #=> String
resp.outputs[0].from_association #=> Boolean
resp.status #=> String, one of "CREATING", "AVAILABLE", "ACTIVE", "UPDATING", "DELETING", "DELETED", "ARCHIVED"
resp.association.associated_resource_name #=> String
resp.tags #=> Hash
resp.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :id (required, String)

    The ID of the feed to query.

Returns:

See Also:



980
981
982
983
# File 'lib/aws-sdk-elementalinference/client.rb', line 980

def get_feed(params = {}, options = {})
  req = build_request(:get_feed, params)
  req.send_request(options)
end

#list_dictionaries(params = {}) ⇒ Types::ListDictionariesResponse

Lists the dictionaries in your account.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_dictionaries({
  max_results: 1,
  next_token: "String",
})

Response structure


resp.dictionaries #=> Array
resp.dictionaries[0].arn #=> String
resp.dictionaries[0].id #=> String
resp.dictionaries[0].name #=> String
resp.dictionaries[0].language #=> String, one of "eng", "fra", "ita", "deu", "spa", "por"
resp.dictionaries[0].status #=> String, one of "CREATING", "AVAILABLE", "REFERENCED", "DELETING", "DELETED"
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :max_results (Integer)

    The maximum number of results to return per API request. Valid range: 1 to 100.

  • :next_token (String)

    The token that identifies the next batch of results to return.

Returns:

See Also:



1022
1023
1024
1025
# File 'lib/aws-sdk-elementalinference/client.rb', line 1022

def list_dictionaries(params = {}, options = {})
  req = build_request(:list_dictionaries, params)
  req.send_request(options)
end

#list_feeds(params = {}) ⇒ Types::ListFeedsResponse

Displays a list of feeds that belong to this AWS account.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_feeds({
  max_results: 1,
  next_token: "String",
})

Response structure


resp.feeds #=> Array
resp.feeds[0].arn #=> String
resp.feeds[0].id #=> String
resp.feeds[0].name #=> String
resp.feeds[0].association.associated_resource_name #=> String
resp.feeds[0].status #=> String, one of "CREATING", "AVAILABLE", "ACTIVE", "UPDATING", "DELETING", "DELETED", "ARCHIVED"
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :max_results (Integer)

    The maximum number of results to return per API request.

    For example, you submit a list request with MaxResults set at 5. Although 20 items match your request, the service returns no more than the first 5 items. (The service also returns a NextToken value that you can use to fetch the next batch of results.)

    The service might return fewer results than the MaxResults value. If MaxResults is not included in the request, the service defaults to pagination with a maximum of 10 results per page.

    Valid Range: Minimum value of 1. Maximum value of 1000.

  • :next_token (String)

    The token that identifies the batch of results that you want to see.

    For example, you submit a ListFeeds request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the ListFeeds request a second time and specify the NextToken value.

Returns:

See Also:



1079
1080
1081
1082
# File 'lib/aws-sdk-elementalinference/client.rb', line 1079

def list_feeds(params = {}, options = {})
  req = build_request(:list_feeds, params)
  req.send_request(options)
end

#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse

List all tags that are on an Elemental Inference resource in the current region.

Examples:

Request syntax with placeholder values


resp = client.list_tags_for_resource({
  resource_arn: "ResourceArn", # required
})

Response structure


resp.tags #=> Hash
resp.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The ARN of the resource whose tags you want to query.

Returns:

See Also:



1109
1110
1111
1112
# File 'lib/aws-sdk-elementalinference/client.rb', line 1109

def list_tags_for_resource(params = {}, options = {})
  req = build_request(:list_tags_for_resource, params)
  req.send_request(options)
end

#tag_resource(params = {}) ⇒ Struct

Associates the specified tags to the resource identified by the specified resourceArn in the current region. If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are also deleted.

Examples:

Request syntax with placeholder values


resp = client.tag_resource({
  resource_arn: "ResourceArn", # required
  tags: { # required
    "TagKey" => "TagValue",
  },
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The ARN of the resource where you want to add tags.

  • :tags (required, Hash<String,String>)

    A list of tags to add to the resource.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1141
1142
1143
1144
# File 'lib/aws-sdk-elementalinference/client.rb', line 1141

def tag_resource(params = {}, options = {})
  req = build_request(:tag_resource, params)
  req.send_request(options)
end

#untag_resource(params = {}) ⇒ Struct

Deletes specified tags from the specified resource in the current region.

Examples:

Request syntax with placeholder values


resp = client.untag_resource({
  resource_arn: "ResourceArn", # required
  tag_keys: ["TagKey"], # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The ARN of the resource where you want to delete one or more tags.

  • :tag_keys (required, Array<String>)

    The keys of the tags to delete.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1168
1169
1170
1171
# File 'lib/aws-sdk-elementalinference/client.rb', line 1168

def untag_resource(params = {}, options = {})
  req = build_request(:untag_resource, params)
  req.send_request(options)
end

#update_dictionary(params = {}) ⇒ Types::UpdateDictionaryResponse

Updates the specified dictionary.

Examples:

Request syntax with placeholder values


resp = client.update_dictionary({
  id: "DictionaryId", # required
  name: "ResourceName",
  language: "eng", # accepts eng, fra, ita, deu, spa, por
  entries: "DictionaryEntriesPayload",
})

Response structure


resp.name #=> String
resp.arn #=> String
resp.id #=> String
resp.language #=> String, one of "eng", "fra", "ita", "deu", "spa", "por"
resp.status #=> String, one of "CREATING", "AVAILABLE", "REFERENCED", "DELETING", "DELETED"
resp.references #=> Array
resp.references[0] #=> String
resp.tags #=> Hash
resp.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :id (required, String)

    The ID of the dictionary to update.

  • :name (String)

    A new name for the dictionary. If not specified, the name is not changed.

  • :language (String)

    A new language for the dictionary. If not specified, the language is not changed.

  • :entries (String)

    New dictionary entries. If not specified, the entries are not changed.

Returns:

See Also:



1224
1225
1226
1227
# File 'lib/aws-sdk-elementalinference/client.rb', line 1224

def update_dictionary(params = {}, options = {})
  req = build_request(:update_dictionary, params)
  req.send_request(options)
end

#update_feed(params = {}) ⇒ Types::UpdateFeedResponse

Updates the name and/or outputs in a feed.

UpdateFeed is a PUT operation, which means that the payload that you specify completely overwrites the existing payload.

This means that if you want to touch the array of outputs, you must pass in the full new list. So you must omit outputs you want to delete, and include outputs you want to add or modify.

If you want to patch the array of outputs to make selective additions, use AssociateFeed.

Examples:

Request syntax with placeholder values


resp = client.update_feed({
  name: "ResourceName", # required
  id: "FeedId", # required
  outputs: [ # required
    {
      name: "ResourceName", # required
      output_config: { # required
        cropping: {
        },
        clipping: {
          callback_metadata: "ResourceDescription",
        },
        subtitling: {
          language: "eng", # required, accepts eng, eng-au, eng-gb, eng-us, fra, ita, deu, spa, por
          aspect_ratio: {
            width: 1, # required
            height: 1, # required
          },
          dictionary: "DictionaryId",
          profanity_filter: "DISABLED", # accepts DISABLED, CENSOR, DROP
        },
      },
      status: "ENABLED", # required, accepts ENABLED, DISABLED
      description: "ResourceDescription",
      from_association: false,
    },
  ],
})

Response structure


resp.arn #=> String
resp.name #=> String
resp.id #=> String
resp.data_endpoints #=> Array
resp.data_endpoints[0] #=> String
resp.outputs #=> Array
resp.outputs[0].name #=> String
resp.outputs[0].output_config.clipping. #=> String
resp.outputs[0].output_config.subtitling.language #=> String, one of "eng", "eng-au", "eng-gb", "eng-us", "fra", "ita", "deu", "spa", "por"
resp.outputs[0].output_config.subtitling.aspect_ratio.width #=> Integer
resp.outputs[0].output_config.subtitling.aspect_ratio.height #=> Integer
resp.outputs[0].output_config.subtitling.dictionary #=> String
resp.outputs[0].output_config.subtitling.profanity_filter #=> String, one of "DISABLED", "CENSOR", "DROP"
resp.outputs[0].status #=> String, one of "ENABLED", "DISABLED"
resp.outputs[0].description #=> String
resp.outputs[0].from_association #=> Boolean
resp.status #=> String, one of "CREATING", "AVAILABLE", "ACTIVE", "UPDATING", "DELETING", "DELETED", "ARCHIVED"
resp.association.associated_resource_name #=> String
resp.tags #=> Hash
resp.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :name (required, String)

    Required. You can specify the existing name (to leave it unchanged) or a new name.

  • :id (required, String)

    The ID of the feed to update.

  • :outputs (required, Array<Types::UpdateOutput>)

    Required. You can specify the existing array of outputs (to leave outputs unchanged) or you can specify a new array.

Returns:

See Also:



1321
1322
1323
1324
# File 'lib/aws-sdk-elementalinference/client.rb', line 1321

def update_feed(params = {}, options = {})
  req = build_request(:update_feed, params)
  req.send_request(options)
end

#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean

Polls an API operation until a resource enters a desired state.

## Basic Usage

A waiter will call an API operation until:

  • It is successful

  • It enters a terminal state

  • It makes the maximum number of attempts

In between attempts, the waiter will sleep.

# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)

## Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.

# poll for ~25 seconds
client.wait_until(waiter_name, params, {
  max_attempts: 5,
  delay: 5,
})

## Callbacks

You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.

started_at = Time.now
client.wait_until(waiter_name, params, {

  # disable max attempts
  max_attempts: nil,

  # poll for 1 hour, instead of a number of attempts
  before_wait: -> (attempts, response) do
    throw :failure if Time.now - started_at > 3600
  end
})

## Handling Errors

When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.

begin
  client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

## Valid Waiters

The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.

| waiter_name | params | :delay | :max_attempts | | ———— | —————– | ——– | ————- | | feed_deleted | #get_feed | 3 | 40 |

Parameters:

  • waiter_name (Symbol)
  • params (Hash) (defaults to: {})

    ({})

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :max_attempts (Integer)
  • :delay (Integer)
  • :before_attempt (Proc)
  • :before_wait (Proc)

Yields:

  • (w.waiter)

Returns:

  • (Boolean)

    Returns ‘true` if the waiter was successful.

Raises:

  • (Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

  • (Errors::TooManyAttemptsError)

    Raised when the configured maximum number of attempts have been made, and the waiter is not yet successful.

  • (Errors::UnexpectedError)

    Raised when an error is encounted while polling for a resource that is not expected.

  • (Errors::NoSuchWaiterError)

    Raised when you request to wait for an unknown state.



1436
1437
1438
1439
1440
# File 'lib/aws-sdk-elementalinference/client.rb', line 1436

def wait_until(waiter_name, params = {}, options = {})
  w = waiter(waiter_name, options)
  yield(w.waiter) if block_given? # deprecated
  w.wait(params)
end

#waiter_namesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


1444
1445
1446
# File 'lib/aws-sdk-elementalinference/client.rb', line 1444

def waiter_names
  waiters.keys
end