Class: Aws::ElementalInference::Types::AssociateFeedRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::AssociateFeedRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_resource_name ⇒ String
An identifier for the resource.
-
#dry_run ⇒ Boolean
Set to true if you want to do a dry run of the associate action.
-
#id ⇒ String
The ID of the feed.
-
#outputs ⇒ Array<Types::CreateOutput>
An array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.
Instance Attribute Details
#associated_resource_name ⇒ String
An identifier for the resource. This name must not resemble an ARN.
The resource is the source media that the feed will process. The name you assign should help you to later identify the source media that belongs to the feed. In this way, you will know which source media to push to the feed (using PutMedia).
**A suitable default value is auto-generated.** You should normally not need to pass this option.
83 84 85 86 87 88 89 90 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 83 class AssociateFeedRequest < Struct.new( :id, :associated_resource_name, :outputs, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Set to true if you want to do a dry run of the associate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions, quota limits exceeded, conflicting outputs, and so on. If the dry run fails, the action returns a 4xx error code. After you’ve fixed the errors, resubmit the request.
83 84 85 86 87 88 89 90 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 83 class AssociateFeedRequest < Struct.new( :id, :associated_resource_name, :outputs, :dry_run) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the feed.
83 84 85 86 87 88 89 90 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 83 class AssociateFeedRequest < Struct.new( :id, :associated_resource_name, :outputs, :dry_run) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::CreateOutput>
An array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.
83 84 85 86 87 88 89 90 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 83 class AssociateFeedRequest < Struct.new( :id, :associated_resource_name, :outputs, :dry_run) SENSITIVE = [] include Aws::Structure end |