Class: Aws::ElementalInference::Types::ClippingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::ClippingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
A type of OutputConfig, used when the output in a feed is for the clip feature.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#callback_metadata ⇒ String
A string that you want Elemental Inference to always include in the event clipping metadata for this output.
-
#data_source_configuration ⇒ Types::DataSourceConfiguration
The data source to map onto this clipping output.
Instance Attribute Details
#callback_metadata ⇒ String
A string that you want Elemental Inference to always include in the event clipping metadata for this output. The string might identify the sports event in the source media, for example.
130 131 132 133 134 135 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 130 class ClippingConfig < Struct.new( :callback_metadata, :data_source_configuration) SENSITIVE = [] include Aws::Structure end |
#data_source_configuration ⇒ Types::DataSourceConfiguration
The data source to map onto this clipping output. This parameter is optional. When you include this parameter, Elemental Inference reads the event data for the fixture that you specify, and includes that data in the event clipping metadata for this output.
If you omit this parameter, Elemental Inference doesn't map a data source onto this output.
130 131 132 133 134 135 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 130 class ClippingConfig < Struct.new( :callback_metadata, :data_source_configuration) SENSITIVE = [] include Aws::Structure end |