Class: Aws::ElementalInference::Types::ClippingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::ClippingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
A type of OutputConfig, used when the output in a feed is for the clip feature.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#callback_metadata ⇒ String
A string that you want Elemental Inference to always include in the event clipping metadata for this output.
Instance Attribute Details
#callback_metadata ⇒ String
A string that you want Elemental Inference to always include in the event clipping metadata for this output. The string might identify the sports event in the source media, for example.
120 121 122 123 124 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 120 class ClippingConfig < Struct.new( :callback_metadata) SENSITIVE = [] include Aws::Structure end |