Class: Aws::ElementalInference::Types::ClippingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::ClippingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
A type of OutputConfig, used when the output in a feed is for the clip feature.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#callback_metadata ⇒ String
The metadata that is the result of the clip request to Elemental Inference.
Instance Attribute Details
#callback_metadata ⇒ String
The metadata that is the result of the clip request to Elemental Inference.
90 91 92 93 94 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 90 class ClippingConfig < Struct.new( :callback_metadata) SENSITIVE = [] include Aws::Structure end |