Class: Aws::ElementalInference::Types::Competitor
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::Competitor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Contains information about one competitor in a fixture. It is used in the FixtureSummary that is in the SearchFixtures response.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_home ⇒ Boolean
Specifies whether this competitor is the home side in the fixture.
-
#name ⇒ String
The name of the competitor, as provided by the data source.
Instance Attribute Details
#is_home ⇒ Boolean
Specifies whether this competitor is the home side in the fixture. If true, this competitor is the home side. If false, this competitor is the away side.
152 153 154 155 156 157 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 152 class Competitor < Struct.new( :name, :is_home) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the competitor, as provided by the data source.
152 153 154 155 156 157 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 152 class Competitor < Struct.new( :name, :is_home) SENSITIVE = [] include Aws::Structure end |