Class: Aws::ElementalInference::Types::CreateFeedRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::CreateFeedRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_role_arn ⇒ String
The ARN of an IAM role that Elemental Inference assumes to access resources in your account on your behalf.
-
#name ⇒ String
A user-friendly name for this feed.
-
#outputs ⇒ Array<Types::CreateOutput>
An array of outputs for this feed.
-
#tags ⇒ Hash<String,String>
Optional tags.
Instance Attribute Details
#access_role_arn ⇒ String
The ARN of an IAM role that Elemental Inference assumes to access resources in your account on your behalf. For example, the smart crop feature uses this role to read graphics-compositing templates from your Amazon S3 bucket. You specify one access role for each feed.
238 239 240 241 242 243 244 245 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 238 class CreateFeedRequest < Struct.new( :name, :access_role_arn, :outputs, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A user-friendly name for this feed.
238 239 240 241 242 243 244 245 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 238 class CreateFeedRequest < Struct.new( :name, :access_role_arn, :outputs, :tags) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::CreateOutput>
An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, there is one output type for the smart crop feature. You must specify at least one output, but you can later add outputs using AssociateFeed, or add, modify, and delete outputs using UpdateFeed.
238 239 240 241 242 243 244 245 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 238 class CreateFeedRequest < Struct.new( :name, :access_role_arn, :outputs, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Optional tags. You can also add tags later, using TagResource.
238 239 240 241 242 243 244 245 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 238 class CreateFeedRequest < Struct.new( :name, :access_role_arn, :outputs, :tags) SENSITIVE = [] include Aws::Structure end |