Class: Aws::ElementalInference::Types::CreateFeedRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

A user-friendly name for this feed.

Returns:

  • (String)


230
231
232
233
234
235
236
# File 'lib/aws-sdk-elementalinference/types.rb', line 230

class CreateFeedRequest < Struct.new(
  :name,
  :outputs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::CreateOutput>

An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, there is one output type for the smart crop feature. You must specify at least one output, but you can later add outputs using AssociateFeed, or add, modify, and delete outputs using UpdateFeed.

Returns:



230
231
232
233
234
235
236
# File 'lib/aws-sdk-elementalinference/types.rb', line 230

class CreateFeedRequest < Struct.new(
  :name,
  :outputs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Optional tags. You can also add tags later, using TagResource.

Returns:

  • (Hash<String,String>)


230
231
232
233
234
235
236
# File 'lib/aws-sdk-elementalinference/types.rb', line 230

class CreateFeedRequest < Struct.new(
  :name,
  :outputs,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end