Class: Aws::ElementalInference::Types::CreateFeedResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

A unique ARN that Elemental Inference assigns to the feed.

Returns:

  • (String)


288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/aws-sdk-elementalinference/types.rb', line 288

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#associationTypes::FeedAssociation

The association for this feed. When you create the feed, this property is empty. You must associate a resource with the feed using AssociateFeed or UpdateFeed.



288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/aws-sdk-elementalinference/types.rb', line 288

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#data_endpointsArray<String>

An array of endpoints for the feed. Typically, there is only one endpoint. The feed receives source media at this endpoint (when the calling application calls PutMedia) and returns the resulting metadata to this endpoint (when the calling application calls GetMetadata).

Returns:

  • (Array<String>)


288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/aws-sdk-elementalinference/types.rb', line 288

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique ID that Elemental Inference assigns to the feed.

Returns:

  • (String)


288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/aws-sdk-elementalinference/types.rb', line 288

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name that you specified in the request.

Returns:

  • (String)


288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/aws-sdk-elementalinference/types.rb', line 288

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::GetOutput>

Repeats the outputs that you specified in the request.

Returns:



288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/aws-sdk-elementalinference/types.rb', line 288

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the feed. After creation of the feed has succeeded, the status will be AVAILABLE.

Returns:

  • (String)


288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/aws-sdk-elementalinference/types.rb', line 288

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Any tags that you included when you created the feed.

Returns:

  • (Hash<String,String>)


288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/aws-sdk-elementalinference/types.rb', line 288

class CreateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end