Class: Aws::ElementalInference::Types::CreateFeedResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::CreateFeedResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
A unique ARN that Elemental Inference assigns to the feed.
-
#association ⇒ Types::FeedAssociation
The association for this feed.
-
#data_endpoints ⇒ Array<String>
An array of endpoints for the feed.
-
#id ⇒ String
A unique ID that Elemental Inference assigns to the feed.
-
#name ⇒ String
The name that you specified in the request.
-
#outputs ⇒ Array<Types::GetOutput>
Repeats the outputs that you specified in the request.
-
#status ⇒ String
The current status of the feed.
-
#tags ⇒ Hash<String,String>
Any tags that you included when you created the feed.
Instance Attribute Details
#arn ⇒ String
A unique ARN that Elemental Inference assigns to the feed.
288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 288 class CreateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#association ⇒ Types::FeedAssociation
The association for this feed. When you create the feed, this property is empty. You must associate a resource with the feed using AssociateFeed or UpdateFeed.
288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 288 class CreateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#data_endpoints ⇒ Array<String>
An array of endpoints for the feed. Typically, there is only one endpoint. The feed receives source media at this endpoint (when the calling application calls PutMedia) and returns the resulting metadata to this endpoint (when the calling application calls GetMetadata).
288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 288 class CreateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique ID that Elemental Inference assigns to the feed.
288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 288 class CreateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that you specified in the request.
288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 288 class CreateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::GetOutput>
Repeats the outputs that you specified in the request.
288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 288 class CreateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the feed. After creation of the feed has succeeded, the status will be AVAILABLE.
288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 288 class CreateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Any tags that you included when you created the feed.
288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 288 class CreateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |