Class: Aws::ElementalInference::Types::CroppingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::CroppingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
A type of OutputConfig, used when the output in a feed is for the crop feature.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#template_groups ⇒ Array<Types::TemplateGroup>
An array of template groups for the crop output.
Instance Attribute Details
#template_groups ⇒ Array<Types::TemplateGroup>
An array of template groups for the crop output. Each template group provides the graphics-compositing templates that Elemental Inference applies to the cropped video. You can specify from 1 to 4 template groups.
346 347 348 349 350 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 346 class CroppingConfig < Struct.new( :template_groups) SENSITIVE = [] include Aws::Structure end |