Class: Aws::ElementalInference::Types::DataSourceConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::DataSourceConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Contains the data source configuration for a clipping output. It identifies the fixture whose event data Elemental Inference maps onto the clipping metadata. It is used in the dataSourceConfiguration property of a ClippingConfig.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fixture_id ⇒ String
The ID of the fixture whose event data you want Elemental Inference to map onto this clipping output.
Instance Attribute Details
#fixture_id ⇒ String
The ID of the fixture whose event data you want Elemental Inference to map onto this clipping output. The fixture should be the sports event in the source media that the feed is processing.
To obtain this ID, use the SearchFixtures operation to find the fixture, then use the fixtureId from the matching FixtureSummary.
401 402 403 404 405 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 401 class DataSourceConfiguration < Struct.new( :fixture_id) SENSITIVE = [] include Aws::Structure end |