Class: Aws::ElementalInference::Types::GetFeedResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_role_arnString

The Amazon Resource Name (ARN) of an AWS Identity and Access Management (IAM) role that Elemental Inference assumes. Elemental Inference uses this role to access resources in your account on your behalf. This property is absent if the feed doesn't have an IAM role.

Returns:

  • (String)


817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'lib/aws-sdk-elementalinference/types.rb', line 817

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN of the feed.

Returns:

  • (String)


817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'lib/aws-sdk-elementalinference/types.rb', line 817

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#associationTypes::FeedAssociation

Information about the resource that is associated with the feed. It's possible that there is no associated resource. This is not an error.



817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'lib/aws-sdk-elementalinference/types.rb', line 817

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#data_endpointsArray<String>

The dataEndpoints of the feed.

Returns:

  • (Array<String>)


817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'lib/aws-sdk-elementalinference/types.rb', line 817

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the feed.

Returns:

  • (String)


817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'lib/aws-sdk-elementalinference/types.rb', line 817

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the feed.

Returns:

  • (String)


817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'lib/aws-sdk-elementalinference/types.rb', line 817

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::GetOutput>

An array of the outputs in the feed.

Returns:



817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'lib/aws-sdk-elementalinference/types.rb', line 817

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the feed.

Returns:

  • (String)


817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'lib/aws-sdk-elementalinference/types.rb', line 817

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A list of the tags, if any, for the feed.

Returns:

  • (Hash<String,String>)


817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'lib/aws-sdk-elementalinference/types.rb', line 817

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end