Class: Aws::ElementalInference::Types::GetFeedResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the feed.

Returns:

  • (String)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-elementalinference/types.rb', line 680

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#associationTypes::FeedAssociation

Information about the resource that is associated with the feed. It's possible that there is no associated resource. This is not an error.



680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-elementalinference/types.rb', line 680

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#data_endpointsArray<String>

The dataEndpoints of the feed.

Returns:

  • (Array<String>)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-elementalinference/types.rb', line 680

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the feed.

Returns:

  • (String)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-elementalinference/types.rb', line 680

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the feed.

Returns:

  • (String)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-elementalinference/types.rb', line 680

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::GetOutput>

An array of the outputs in the feed.

Returns:



680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-elementalinference/types.rb', line 680

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the feed.

Returns:

  • (String)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-elementalinference/types.rb', line 680

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A list of the tags, if any, for the feed.

Returns:

  • (Hash<String,String>)


680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-elementalinference/types.rb', line 680

class GetFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end