Class: Aws::ElementalInference::Types::GetFeedResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::GetFeedResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the feed.
-
#association ⇒ Types::FeedAssociation
Information about the resource that is associated with the feed.
-
#data_endpoints ⇒ Array<String>
The dataEndpoints of the feed.
-
#id ⇒ String
The ID of the feed.
-
#name ⇒ String
The name of the feed.
-
#outputs ⇒ Array<Types::GetOutput>
An array of the outputs in the feed.
-
#status ⇒ String
The status of the feed.
-
#tags ⇒ Hash<String,String>
A list of the tags, if any, for the feed.
Instance Attribute Details
#arn ⇒ String
The ARN of the feed.
680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 680 class GetFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#association ⇒ Types::FeedAssociation
Information about the resource that is associated with the feed. It's possible that there is no associated resource. This is not an error.
680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 680 class GetFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#data_endpoints ⇒ Array<String>
The dataEndpoints of the feed.
680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 680 class GetFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the feed.
680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 680 class GetFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the feed.
680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 680 class GetFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::GetOutput>
An array of the outputs in the feed.
680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 680 class GetFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the feed.
680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 680 class GetFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of the tags, if any, for the feed.
680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 680 class GetFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |