Class: Aws::ElementalInference::Types::GetOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::GetOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Contains configuration information about one output in a feed. It is used in the GetFeed response.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the output.
-
#from_association ⇒ Boolean
True means that the output was originally created in the feed using AssociateFeed.
-
#name ⇒ String
The name of the output.
-
#output_config ⇒ Types::OutputConfig
A typed property for an output in a feed.
-
#status ⇒ String
The status of the output.
Instance Attribute Details
#description ⇒ String
The description of the output.
708 709 710 711 712 713 714 715 716 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 708 class GetOutput < Struct.new( :name, :output_config, :status, :description, :from_association) SENSITIVE = [] include Aws::Structure end |
#from_association ⇒ Boolean
True means that the output was originally created in the feed using AssociateFeed. False means it was created using CreateFeed or UpdateFeed.
You will need this value if you use UpdateFeed to modify the list of outputs in the feed.
708 709 710 711 712 713 714 715 716 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 708 class GetOutput < Struct.new( :name, :output_config, :status, :description, :from_association) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the output.
708 709 710 711 712 713 714 715 716 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 708 class GetOutput < Struct.new( :name, :output_config, :status, :description, :from_association) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::OutputConfig
A typed property for an output in a feed. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.
708 709 710 711 712 713 714 715 716 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 708 class GetOutput < Struct.new( :name, :output_config, :status, :description, :from_association) SENSITIVE = [] include Aws::Structure end |