Class: Aws::ElementalInference::Types::OutputConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Note:

OutputConfig is a union - when making an API calls you must set exactly one of the members.

Note:

OutputConfig is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OutputConfig corresponding to the set member.

Contains one typed output. It is used in the CreateOutput, GetOutput, and Update Output structures.

Direct Known Subclasses

Clipping, Cropping, Subtitling, Unknown

Defined Under Namespace

Classes: Clipping, Cropping, Subtitling, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clippingTypes::ClippingConfig

The output config type that applies to the clipping feature.



867
868
869
870
871
872
873
874
875
876
877
878
879
880
# File 'lib/aws-sdk-elementalinference/types.rb', line 867

class OutputConfig < Struct.new(
  :cropping,
  :clipping,
  :subtitling,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Cropping < OutputConfig; end
  class Clipping < OutputConfig; end
  class Subtitling < OutputConfig; end
  class Unknown < OutputConfig; end
end

#croppingTypes::CroppingConfig

The output config type that applies to the cropping feature.



867
868
869
870
871
872
873
874
875
876
877
878
879
880
# File 'lib/aws-sdk-elementalinference/types.rb', line 867

class OutputConfig < Struct.new(
  :cropping,
  :clipping,
  :subtitling,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Cropping < OutputConfig; end
  class Clipping < OutputConfig; end
  class Subtitling < OutputConfig; end
  class Unknown < OutputConfig; end
end

#subtitlingTypes::SubtitlingConfig

The output config type that applies to the smart subtitling feature.



867
868
869
870
871
872
873
874
875
876
877
878
879
880
# File 'lib/aws-sdk-elementalinference/types.rb', line 867

class OutputConfig < Struct.new(
  :cropping,
  :clipping,
  :subtitling,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Cropping < OutputConfig; end
  class Clipping < OutputConfig; end
  class Subtitling < OutputConfig; end
  class Unknown < OutputConfig; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



867
868
869
# File 'lib/aws-sdk-elementalinference/types.rb', line 867

def unknown
  @unknown
end