Class: Aws::ElementalInference::Types::SearchFixturesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::SearchFixturesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_date ⇒ String
The last day of the search window, in UTC.
-
#filters ⇒ Array<Types::SearchFilter>
An array of filters that narrow the results.
-
#max_results ⇒ Integer
The maximum number of fixtures to return for each API request.
-
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
-
#sport ⇒ String
The sport to search for fixtures.
-
#start_date ⇒ String
The first day of the search window, in UTC.
Instance Attribute Details
#end_date ⇒ String
The last day of the search window, in UTC. The search includes
fixtures that are scheduled on this day. Specify the date in ISO
8601 format, as YYYY-MM-DD.
If you omit this parameter, Elemental Inference searches only the day that you specified in startDate. The window from startDate through endDate must not exceed seven days.
1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1111 class SearchFixturesRequest < Struct.new( :sport, :start_date, :end_date, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::SearchFilter>
An array of filters that narrow the results. Each filter applies to one dimension of a fixture, such as the competitor. You can specify up to 10 filters.
A fixture must satisfy every filter in the array in order to appear in the results. Within one filter, a fixture must match at least one of the values.
1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1111 class SearchFixturesRequest < Struct.new( :sport, :start_date, :end_date, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of fixtures to return for each API request.
The service might return fewer fixtures than the maxResults value. When more fixtures match the search, the response also includes a nextToken value that you can use to fetch the next batch of results.
1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1111 class SearchFixturesRequest < Struct.new( :sport, :start_date, :end_date, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token that identifies the batch of results that you want to see.
For example, you submit a SearchFixtures request with maxResults set at 5. The service returns the first batch of results (up to 5) and a nextToken value. To see the next batch of results, you submit the SearchFixtures request a second time, with the same search criteria, and specify the nextToken value.
1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1111 class SearchFixturesRequest < Struct.new( :sport, :start_date, :end_date, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#sport ⇒ String
The sport to search for fixtures. Valid values: basketball (search for basketball fixtures), american-football (search for american-football fixtures).
1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1111 class SearchFixturesRequest < Struct.new( :sport, :start_date, :end_date, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ String
The first day of the search window, in UTC. The search includes fixtures that are scheduled on this day.
Specify the date in ISO 8601 format, as YYYY-MM-DD. For example,
2026-03-14.
1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1111 class SearchFixturesRequest < Struct.new( :sport, :start_date, :end_date, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |