Class: Aws::ElementalInference::Types::SubtitlingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::SubtitlingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
A type of OutputConfig, used when the output in a feed is for the smart subtitling feature. smart subtitling uses automatic speech recognition (ASR) to generate live TTML subtitles from the audio in your source media.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aspect_ratio ⇒ Types::AspectRatio
The aspect ratio of the output video, specified as width and height integer values.
-
#dictionary ⇒ String
The ID of a custom dictionary to improve transcription accuracy for domain-specific terminology.
-
#language ⇒ String
The language of the audio in the source media.
-
#profanity_filter ⇒ String
Controls how profanity is handled in the generated subtitles.
Instance Attribute Details
#aspect_ratio ⇒ Types::AspectRatio
The aspect ratio of the output video, specified as width and height integer values. Elemental Inference uses the aspect ratio to determine subtitle layout and line lengths.
943 944 945 946 947 948 949 950 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 943 class SubtitlingConfig < Struct.new( :language, :aspect_ratio, :dictionary, :profanity_filter) SENSITIVE = [] include Aws::Structure end |
#dictionary ⇒ String
The ID of a custom dictionary to improve transcription accuracy for domain-specific terminology. Use the CreateDictionary operation to create a dictionary.
943 944 945 946 947 948 949 950 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 943 class SubtitlingConfig < Struct.new( :language, :aspect_ratio, :dictionary, :profanity_filter) SENSITIVE = [] include Aws::Structure end |
#language ⇒ String
The language of the audio in the source media. Elemental Inference uses this setting to optimize transcription accuracy. Specify the language using an ISO 639-2/T three-letter code, optionally with a region subtag. Supported values: eng, eng-au, eng-gb, eng-us, fra, ita, deu, spa, por.
943 944 945 946 947 948 949 950 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 943 class SubtitlingConfig < Struct.new( :language, :aspect_ratio, :dictionary, :profanity_filter) SENSITIVE = [] include Aws::Structure end |
#profanity_filter ⇒ String
Controls how profanity is handled in the generated subtitles. Valid values: DISABLED (no filtering, default), CENSOR (replace profanity with asterisks), DROP (remove profanity from the transcript).
943 944 945 946 947 948 949 950 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 943 class SubtitlingConfig < Struct.new( :language, :aspect_ratio, :dictionary, :profanity_filter) SENSITIVE = [] include Aws::Structure end |