Class: Aws::ElementalInference::Types::UpdateFeedRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::UpdateFeedRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_role_arn ⇒ String
The ARN of an IAM role that Elemental Inference assumes to access resources in your account on your behalf.
-
#id ⇒ String
The ID of the feed to update.
-
#name ⇒ String
Required.
-
#outputs ⇒ Array<Types::UpdateOutput>
Required.
Instance Attribute Details
#access_role_arn ⇒ String
The ARN of an IAM role that Elemental Inference assumes to access resources in your account on your behalf. You can specify the existing role (to leave it unchanged) or a new role. You specify one access role for each feed.
1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1383 class UpdateFeedRequest < Struct.new( :name, :access_role_arn, :id, :outputs) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the feed to update.
1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1383 class UpdateFeedRequest < Struct.new( :name, :access_role_arn, :id, :outputs) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Required. You can specify the existing name (to leave it unchanged) or a new name.
1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1383 class UpdateFeedRequest < Struct.new( :name, :access_role_arn, :id, :outputs) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::UpdateOutput>
Required. You can specify the existing array of outputs (to leave outputs unchanged) or you can specify a new array.
1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1383 class UpdateFeedRequest < Struct.new( :name, :access_role_arn, :id, :outputs) SENSITIVE = [] include Aws::Structure end |