Class: Aws::ElementalInference::Types::UpdateFeedRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_role_arnString

The ARN of an IAM role that Elemental Inference assumes to access resources in your account on your behalf. You can specify the existing role (to leave it unchanged) or a new role. You specify one access role for each feed.

Returns:

  • (String)


1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/aws-sdk-elementalinference/types.rb', line 1138

class UpdateFeedRequest < Struct.new(
  :name,
  :access_role_arn,
  :id,
  :outputs)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the feed to update.

Returns:

  • (String)


1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/aws-sdk-elementalinference/types.rb', line 1138

class UpdateFeedRequest < Struct.new(
  :name,
  :access_role_arn,
  :id,
  :outputs)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Required. You can specify the existing name (to leave it unchanged) or a new name.

Returns:

  • (String)


1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/aws-sdk-elementalinference/types.rb', line 1138

class UpdateFeedRequest < Struct.new(
  :name,
  :access_role_arn,
  :id,
  :outputs)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::UpdateOutput>

Required. You can specify the existing array of outputs (to leave outputs unchanged) or you can specify a new array.

Returns:



1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/aws-sdk-elementalinference/types.rb', line 1138

class UpdateFeedRequest < Struct.new(
  :name,
  :access_role_arn,
  :id,
  :outputs)
  SENSITIVE = []
  include Aws::Structure
end