Class: Aws::ElementalInference::Types::UpdateFeedResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_role_arnString

The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role for the feed, after the update. This property is absent if the feed doesn't have an IAM role.

Returns:

  • (String)


1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN of the feed.

Returns:

  • (String)


1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#associationTypes::FeedAssociation

Information about the resource that is associated with the feed, if any.



1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#data_endpointsArray<String>

The data endpoints of the feed.

Returns:

  • (Array<String>)


1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the feed.

Returns:

  • (String)


1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The updated or original name of the feed.

Returns:

  • (String)


1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::GetOutput>

The array of outputs in the feed. You might have left this array unchanged, or you might have changed it.

Returns:



1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the feed.

Returns:

  • (String)


1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags associated with the feed.

Returns:

  • (Hash<String,String>)


1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :access_role_arn,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end