Class: Aws::ElementalInference::Types::UpdateFeedResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::UpdateFeedResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_role_arn ⇒ String
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role for the feed, after the update.
-
#arn ⇒ String
The ARN of the feed.
-
#association ⇒ Types::FeedAssociation
Information about the resource that is associated with the feed, if any.
-
#data_endpoints ⇒ Array<String>
The data endpoints of the feed.
-
#id ⇒ String
The ID of the feed.
-
#name ⇒ String
The updated or original name of the feed.
-
#outputs ⇒ Array<Types::GetOutput>
The array of outputs in the feed.
-
#status ⇒ String
The status of the feed.
-
#tags ⇒ Hash<String,String>
The tags associated with the feed.
Instance Attribute Details
#access_role_arn ⇒ String
The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role for the feed, after the update. This property is absent if the feed doesn't have an IAM role.
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :access_role_arn, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the feed.
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :access_role_arn, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#association ⇒ Types::FeedAssociation
Information about the resource that is associated with the feed, if any.
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :access_role_arn, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#data_endpoints ⇒ Array<String>
The data endpoints of the feed.
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :access_role_arn, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the feed.
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :access_role_arn, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The updated or original name of the feed.
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :access_role_arn, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::GetOutput>
The array of outputs in the feed. You might have left this array unchanged, or you might have changed it.
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :access_role_arn, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the feed.
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :access_role_arn, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the feed.
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1505 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :access_role_arn, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |