Class: Aws::ElementalInference::Types::UpdateFeedResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::UpdateFeedResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the feed.
-
#association ⇒ Types::FeedAssociation
Information about the resource that is associated with the feed, if any.
-
#data_endpoints ⇒ Array<String>
The data endpoints of the feed.
-
#id ⇒ String
The ID of the feed.
-
#name ⇒ String
The updated or original name of the feed.
-
#outputs ⇒ Array<Types::GetOutput>
The array of outputs in the feed.
-
#status ⇒ String
The status of the feed.
-
#tags ⇒ Hash<String,String>
The tags associated with the feed.
Instance Attribute Details
#arn ⇒ String
The ARN of the feed.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1183 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#association ⇒ Types::FeedAssociation
Information about the resource that is associated with the feed, if any.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1183 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#data_endpoints ⇒ Array<String>
The data endpoints of the feed.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1183 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the feed.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1183 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The updated or original name of the feed.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1183 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::GetOutput>
The array of outputs in the feed. You might have left this array unchanged, or you might have changed it.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1183 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the feed.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1183 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the feed.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1183 class UpdateFeedResponse < Struct.new( :arn, :name, :id, :data_endpoints, :outputs, :status, :association, :tags) SENSITIVE = [] include Aws::Structure end |