Class: Aws::ElementalInference::Types::UpdateFeedResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the feed.

Returns:

  • (String)


1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
# File 'lib/aws-sdk-elementalinference/types.rb', line 1133

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#associationTypes::FeedAssociation

Information about the resource that is associated with the feed, if any.



1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
# File 'lib/aws-sdk-elementalinference/types.rb', line 1133

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#data_endpointsArray<String>

The data endpoints of the feed.

Returns:

  • (Array<String>)


1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
# File 'lib/aws-sdk-elementalinference/types.rb', line 1133

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the feed.

Returns:

  • (String)


1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
# File 'lib/aws-sdk-elementalinference/types.rb', line 1133

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The updated or original name of the feed.

Returns:

  • (String)


1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
# File 'lib/aws-sdk-elementalinference/types.rb', line 1133

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::GetOutput>

The array of outputs in the feed. You might have left this array unchanged, or you might have changed it.

Returns:



1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
# File 'lib/aws-sdk-elementalinference/types.rb', line 1133

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the feed.

Returns:

  • (String)


1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
# File 'lib/aws-sdk-elementalinference/types.rb', line 1133

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags associated with the feed.

Returns:

  • (Hash<String,String>)


1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
# File 'lib/aws-sdk-elementalinference/types.rb', line 1133

class UpdateFeedResponse < Struct.new(
  :arn,
  :name,
  :id,
  :data_endpoints,
  :outputs,
  :status,
  :association,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end