Class: Aws::ElementalInference::Types::UpdateOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

Contains configuration information about one output in a feed. It is used in the UpdateFeed action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the output.

Returns:

  • (String)


1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-elementalinference/types.rb', line 1181

class UpdateOutput < Struct.new(
  :name,
  :output_config,
  :status,
  :description,
  :from_association)
  SENSITIVE = []
  include Aws::Structure
end

#from_associationBoolean

Elemental Inference originally sets this parameter to True if this output was created by AssociateFeed or to False if this output was created by CreateFeed or UpdateFeed.

You must not change this value. Therefore, use GetFeed to determine the current value. Then in the UpdateFeed request, if the current value is True, include this parameter with a value of True. If it’s False, omit the parameter.

Returns:

  • (Boolean)


1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-elementalinference/types.rb', line 1181

class UpdateOutput < Struct.new(
  :name,
  :output_config,
  :status,
  :description,
  :from_association)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the output.

Returns:

  • (String)


1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-elementalinference/types.rb', line 1181

class UpdateOutput < Struct.new(
  :name,
  :output_config,
  :status,
  :description,
  :from_association)
  SENSITIVE = []
  include Aws::Structure
end

#output_configTypes::OutputConfig

A typed property for an output in a feed. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.

Returns:



1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-elementalinference/types.rb', line 1181

class UpdateOutput < Struct.new(
  :name,
  :output_config,
  :status,
  :description,
  :from_association)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the output.

Returns:

  • (String)


1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-elementalinference/types.rb', line 1181

class UpdateOutput < Struct.new(
  :name,
  :output_config,
  :status,
  :description,
  :from_association)
  SENSITIVE = []
  include Aws::Structure
end