Class: Aws::ElementalInference::Types::UpdateOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElementalInference::Types::UpdateOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elementalinference/types.rb
Overview
Contains configuration information about one output in a feed. It is used in the UpdateFeed action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the output.
-
#from_association ⇒ Boolean
Elemental Inference originally sets this parameter to True if this output was created by AssociateFeed or to False if this output was created by CreateFeed or UpdateFeed.
-
#name ⇒ String
The name of the output.
-
#output_config ⇒ Types::OutputConfig
A typed property for an output in a feed.
-
#status ⇒ String
The status of the output.
Instance Attribute Details
#description ⇒ String
A description of the output.
1181 1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1181 class UpdateOutput < Struct.new( :name, :output_config, :status, :description, :from_association) SENSITIVE = [] include Aws::Structure end |
#from_association ⇒ Boolean
Elemental Inference originally sets this parameter to True if this output was created by AssociateFeed or to False if this output was created by CreateFeed or UpdateFeed.
You must not change this value. Therefore, use GetFeed to determine the current value. Then in the UpdateFeed request, if the current value is True, include this parameter with a value of True. If it’s False, omit the parameter.
1181 1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1181 class UpdateOutput < Struct.new( :name, :output_config, :status, :description, :from_association) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the output.
1181 1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1181 class UpdateOutput < Struct.new( :name, :output_config, :status, :description, :from_association) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::OutputConfig
A typed property for an output in a feed. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.
1181 1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1181 class UpdateOutput < Struct.new( :name, :output_config, :status, :description, :from_association) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the output.
1181 1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-elementalinference/types.rb', line 1181 class UpdateOutput < Struct.new( :name, :output_config, :status, :description, :from_association) SENSITIVE = [] include Aws::Structure end |