Class: Aws::ElementalInference::Types::ValidationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

The input fails to satisfy the constraints specified by the service. Check the error message for details about which parameter or field is invalid and correct the request before retrying.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


1495
1496
1497
1498
1499
# File 'lib/aws-sdk-elementalinference/types.rb', line 1495

class ValidationException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end