Class: Aws::ElementalInference::Types::ValidationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elementalinference/types.rb

Overview

The input fails to satisfy the constraints specified by the service. Check the error message for details about which parameter or field is invalid and correct the request before retrying.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


1250
1251
1252
1253
1254
# File 'lib/aws-sdk-elementalinference/types.rb', line 1250

class ValidationException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end